
/**
 * Beispiele für diverse Graphen
 * 
 * @author Albert Wiedemann
 * @version 1.0
 */
class Beispiele
{
    /** Der Graph */
    private GraphListe g;
    /** Das Leseobjekt */
    private Lesen l;
    
    /**
     * Legt das Graphenobjekt an.
     */
    Beispiele ()
    {
        g = new GraphListe();
        l = new Lesen();
    }

    /**
     * Legt den Graphen für das Beispiel im Lehrtext an.
     * Am Ende Ausgabe der Adjazenzmatrix zur Kontrolle
     */
    void AusführenAbiturfahrt()
    {
        g.ZurückSetzen();
        if (l.LesenDatenbank("Abiturfahrt.grdb", g))
        {
            g.Ausgeben();
        }
    }

    /**
     * Legt einen Graphen für den süddeutschen Teil des Autobahnnetztes an.
     * Am Ende Ausgabe der Adjazenzmatrix zur Kontrolle
     */
    void AusführenAutobahn()
    {
        g.ZurückSetzen();
        if (l.LesenDatenbank("Autobahnen.grdb", g))
        {
            g.Ausgeben();
        }
    }
 

    /**
     * Legt einen Graphen für dei gegebenen Flugverbindungen an.
     * Am Ende Ausgabe der Adjazenzmatrix zur Kontrolle
     */
    void AusführenFlug()
    {
        g.ZurückSetzen();
        if (l.LesenDatenbank("Fluglinien.grdb", g))
        {
            g.Ausgeben();
        }
    }
   
    /**
     * Legt einen Graphen für das deutsche ICE-Netzt an.
     * Am Ende Ausgabe der Adjazenzmatrix zur Kontrolle
     */
    void AusführenICE()
    {
        g.ZurückSetzen();
        if (l.LesenDatenbank("ICENetz.grdb", g))
        {
            g.Ausgeben();
        }
    }

    /**
     * Legt einen Graphen für das Münchner S-U-Bahn-Netzt an.
     * Am Ende Ausgabe der Adjazenzmatrix zur Kontrolle
     */
    void AusführenSUBahn()
    {
        g.ZurückSetzen();
        if (l.LesenDatenbank("SUBahn.grdb", g))
        {
            g.Ausgeben();
        }
    }

    /**
     * Legt einen zusammenhängenden Graphen an.
     * Am Ende Ausgabe der Adjazenzmatrix zur Kontrolle
     */
    void AusführenBeispielgraph()
    {
        g.ZurückSetzen();
        if (l.LesenDatenbank("Beispielgraph.grdb", g))
        {
            g.Ausgeben();
        }
    }

    /**
     * Legt einen nicht zusammenhängenden Graphen an.
     * Am Ende Ausgabe der Adjazenzmatrix zur Kontrolle
     */
    void AusführenUngeeignetesBeispiel()
    {
        g.ZurückSetzen();
        if (l.LesenDatenbank("Beispielgraph2.grdb", g))
        {
            g.Ausgeben();
        }
    }

    /**
     * Führt den Dijkstra-Algorithmus vom Startknoten zum Zielknoten durch
     * @param nameStartKnoten der Bezeichner des Startknotens
     * @param nameZielKnoten der Bezeichner des Zielknotens
     */
    void DijkstraAusführen (String nameStartKnoten, String nameZielKnoten)
    {
        if (g != null)
        {
            g.DijkstraAusführen(g.KnotenGeben(nameStartKnoten), g.KnotenGeben(nameZielKnoten));
        }
    }

}
